<?php
require_once 'PHPUnit2/Framework/TestCase.php';
include_once "Zend.php";

class ConfigIniTest extends PHPUnit2_Framework_TestCase
{
    protected $_iniFileConfig;
    protected $_iniFileOne;
    protected $_iniFileTwo;

    function setUp()
    {
        Zend::loadClass('Akrabat_Config_Ini');
        $this->_iniFileConfig = dirname(__FILE__).'/testData/config.ini';
        $this->_iniFileOne = dirname(__FILE__).'/testData/one.ini';
        $this->_iniFileTwo = dirname(__FILE__).'/testData/two.ini';
    }

    function tearDown()
    {
    }


    function testLoadSectionAll()
    {
        $config = new Akrabat_Config_Ini($this->_iniFileConfig, 'all');
        $this->assertEquals('all', $config->hostname);
        $this->assertEquals('all', $config->test['me']);
    }

    function testSectionInclude()
    {
        $config = new Akrabat_Config_Ini($this->_iniFileConfig, 'staging');
        $this->assertEquals('staging', $config->hostname);
        $this->assertEquals('staging', $config->test['me']);
        $this->assertEquals('2', $config->secondVar);
    }

    function testSectionMultiLevels()
    {
        $config = new Akrabat_Config_Ini($this->_iniFileConfig, 'multi');

        $this->assertEquals('four', $config->one['two.three']);
        $this->assertEquals('five', $config->one['two.three.four']);
        $this->assertEquals('dotdotthree',$config->one['two..three']);
    }

    function testSectionLeadingDot()
    {
        $config = new Akrabat_Config_Ini($this->_iniFileConfig, 'dot');
        $this->assertEquals('dot', $config->get("."));
        $this->assertEquals('doubledot', $config->get(".."));
        $this->assertEquals('t-dot', $config->get("t."));
        $this->assertEquals('dot-t', $config->get(".t"));
    }

    function testLoadEntireConfigFile()
    {
        $config = new Akrabat_Config_Ini($this->_iniFileConfig);

        $this->assertEquals('all', $config->all['hostname']);
        $this->assertEquals('all', $config->all['test']['me']);

        // ensure that the include=all in "staging" works
        $this->assertEquals('avalue', $config->staging['akey']);

        // test multi-level
        $multi = $config->get('multi');
        $this->assertEquals('four', $multi['one']['two.three']);

        // test top level
        $this->assertEquals('1', $config->toplevel);
    }

    function testReadOnly()
    {
        $config = new Akrabat_Config_Ini($this->_iniFileConfig);
        try {
            $config->test = '32';
        }
        catch (Exception $expected) {
            return;
        }

        $this->fail('An expected Exception has not been raised.');
    }

    function testSecondFileOverwritesFirst()
    {
        $config = new Akrabat_Config_Ini();
        $config->load($this->_iniFileOne);
        $this->assertEquals('one', $config->akey);

        $config->load($this->_iniFileTwo);
        $this->assertEquals('two', $config->akey);

        $this->assertEquals('two', $config->db['hostname']);
        $this->assertEquals('thisDb', $config->db['database']);
    }

    function testNestedOverridesOneSection()
    {
        $config = new Akrabat_Config_Ini($this->_iniFileConfig, 'test');
        $this->assertEquals('test', $config->db['name']);
        $this->assertEquals('username', $config->db['user']);

    }

    function testNestedOverridesMultiSection()
    {
        $config = new Akrabat_Config_Ini($this->_iniFileConfig);
        $this->assertEquals('test', $config->test['db']['name']);
        $this->assertEquals('username', $config->test['db']['user']);

    }
}

?>